@@ -3,7 +3,6 @@ import os
 import sys
 import unittest
 import io
-import re
 
 from xml.sax.saxutils import XMLGenerator
 from xml.sax import SAXParseException
@@ -11,9 +10,9 @@ from pyexpat import ExpatError
 
 from defusedxml import cElementTree, ElementTree, minidom, pulldom, sax, xmlrpc
 from defusedxml import defuse_stdlib
-from defusedxml import (DefusedXmlException, DTDForbidden, EntitiesForbidden,
+from defusedxml import (DTDForbidden, EntitiesForbidden,
                         ExternalReferenceForbidden, NotSupportedError)
-from defusedxml.common import PY3, PY26, PY31
+from defusedxml.common import PY3
 
 
 try:
@@ -39,39 +38,6 @@ os.environ["http_proxy"] = "http://127.0.9.1:9"
 os.environ["https_proxy"] = os.environ["http_proxy"]
 os.environ["ftp_proxy"] = os.environ["http_proxy"]
 
-if PY26 or PY31:
-    class _AssertRaisesContext(object):
-        def __init__(self, expected, test_case, expected_regexp=None):
-            self.expected = expected
-            self.failureException = test_case.failureException
-            self.expected_regexp = expected_regexp
-
-        def __enter__(self):
-            return self
-
-        def __exit__(self, exc_type, exc_value, tb):
-            if exc_type is None:
-                try:
-                    exc_name = self.expected.__name__
-                except AttributeError:
-                    exc_name = str(self.expected)
-                raise self.failureException(
-                    "{0} not raised".format(exc_name))
-            if not issubclass(exc_type, self.expected):
-                # let unexpected exceptions pass through
-                return False
-            self.exception = exc_value # store for later retrieval
-            if self.expected_regexp is None:
-                return True
-
-            expected_regexp = self.expected_regexp
-            if isinstance(expected_regexp, basestring):
-                expected_regexp = re.compile(expected_regexp)
-            if not expected_regexp.search(str(exc_value)):
-                raise self.failureException('"%s" does not match "%s"' %
-                         (expected_regexp.pattern, str(exc_value)))
-            return True
-
 
 class DefusedTestCase(unittest.TestCase):
 
@@ -90,21 +56,6 @@ class DefusedTestCase(unittest.TestCase):
     xml_bomb2 = os.path.join(HERE, "xmltestdata", "xmlbomb2.xml")
     xml_cyclic = os.path.join(HERE, "xmltestdata", "cyclic.xml")
 
-    if PY26 or PY31:
-        # old Python versions don't have these useful test methods
-        def assertRaises(self, excClass, callableObj=None, *args, **kwargs):
-            context = _AssertRaisesContext(excClass, self)
-            if callableObj is None:
-                return context
-            with context:
-                callableObj(*args, **kwargs)
-
-        def assertIn(self, member, container, msg=None):
-            if member not in container:
-                standardMsg = '%s not found in %s' % (repr(member),
-                                                      repr(container))
-                self.fail(self._formatMessage(msg, standardMsg))
-
     def get_content(self, xmlfile):
         mode = "rb" if self.content_binary else "r"
         with io.open(xmlfile, mode) as f:
@@ -189,7 +140,6 @@ class BaseTests(DefusedTestCase):
             self.assertRaises(DTDForbidden, self.iterparse,
                               self.xml_dtd, forbid_dtd=True)
 
-
     def test_dtd_with_external_ref(self):
         if self.dtd_external_ref:
             self.assertRaises(self.external_ref_exception, self.parse,
@@ -220,9 +170,8 @@ class BaseTests(DefusedTestCase):
 class TestDefusedElementTree(BaseTests):
     module = ElementTree
 
-
-    ## etree doesn't do external ref lookup
-    #external_ref_exception = ElementTree.ParseError
+    # etree doesn't do external ref lookup
+    # external_ref_exception = ElementTree.ParseError
 
     cyclic_error = ElementTree.ParseError
 
@@ -247,7 +196,6 @@ class TestDefusedMinidom(BaseTests):
 
     cyclic_error = ExpatError
 
-
     iterparse = None
 
     def parse(self, xmlfile, **kwargs):
@@ -302,10 +250,6 @@ class TestDefusedSax(BaseTests):
         return result.getvalue()
 
     def test_exceptions(self):
-        if PY26:
-            # Python 2.6 unittest doesn't support with self.assertRaises()
-            return
-
         with self.assertRaises(EntitiesForbidden) as ctx:
             self.parse(self.xml_bomb)
         msg = "EntitiesForbidden(name='a', system_id=None, public_id=None)"
@@ -334,11 +278,17 @@ class TestDefusedLxml(BaseTests):
     content_binary = True
 
     def parse(self, xmlfile, **kwargs):
-        tree = self.module.parse(xmlfile, **kwargs)
+        try:
+            tree = self.module.parse(xmlfile, **kwargs)
+        except XMLSyntaxError:
+            self.skipTest("lxml detects entityt reference loop")
         return self.module.tostring(tree)
 
     def parseString(self, xmlstring, **kwargs):
-        tree = self.module.fromstring(xmlstring, **kwargs)
+        try:
+            tree = self.module.fromstring(xmlstring, **kwargs)
+        except XMLSyntaxError:
+            self.skipTest("lxml detects entityt reference loop")
         return self.module.tostring(tree)
 
     if not LXML3:
@@ -355,8 +305,11 @@ class TestDefusedLxml(BaseTests):
         pass
 
     def test_restricted_element1(self):
-        tree = self.module.parse(self.xml_bomb, forbid_dtd=False,
-                                 forbid_entities=False)
+        try:
+            tree = self.module.parse(self.xml_bomb, forbid_dtd=False,
+                                     forbid_entities=False)
+        except XMLSyntaxError:
+            self.skipTest("lxml detects entityt reference loop")
         root = tree.getroot()
         self.assertEqual(root.text, None)
 
@@ -370,8 +323,11 @@ class TestDefusedLxml(BaseTests):
         self.assertEqual(root.getnext(), None)
 
     def test_restricted_element2(self):
-        tree = self.module.parse(self.xml_bomb2, forbid_dtd=False,
-                                 forbid_entities=False)
+        try:
+            tree = self.module.parse(self.xml_bomb2, forbid_dtd=False,
+                                     forbid_entities=False)
+        except XMLSyntaxError:
+            self.skipTest("lxml detects entityt reference loop")
         root = tree.getroot()
         bomb, tag = root
         self.assertEqual(root.text, "text")
@@ -416,6 +372,7 @@ class TestDefusedLxml(BaseTests):
 
 
 class XmlRpcTarget(object):
+
     def __init__(self):
         self._data = []
 
@@ -434,8 +391,10 @@ class XmlRpcTarget(object):
     def end(self, tag):
         self._data.append("</%s>" % tag)
 
+
 class TestXmlRpc(DefusedTestCase):
     module = xmlrpc
+
     def parse(self, xmlfile, **kwargs):
         target = XmlRpcTarget()
         parser = self.module.DefusedExpatParser(target, **kwargs)
@@ -459,7 +418,7 @@ class TestXmlRpc(DefusedTestCase):
         self.assertRaises(DTDForbidden, self.parse, self.xml_dtd,
                           forbid_dtd=True)
 
-    #def test_xmlrpc_unpatched(self):
+    # def test_xmlrpc_unpatched(self):
     #    for fname in (self.xml_external,  self.xml_dtd):
     #        print(self.parse_unpatched(fname))
 
@@ -471,6 +430,7 @@ class TestXmlRpc(DefusedTestCase):
 
 
 class TestDefusedGzip(DefusedTestCase):
+
     def get_gzipped(self, length):
         f = io.BytesIO()
         gzf = gzip.GzipFile(mode="wb", fileobj=f)
@@ -492,11 +452,11 @@ class TestDefusedGzip(DefusedTestCase):
     def test_defused_gzip_decode(self):
         data = self.get_gzipped(4096).getvalue()
         result = xmlrpc.defused_gzip_decode(data)
-        self.assertEqual(result, b"d" *4096)
+        self.assertEqual(result, b"d" * 4096)
         result = xmlrpc.defused_gzip_decode(data, -1)
-        self.assertEqual(result, b"d" *4096)
+        self.assertEqual(result, b"d" * 4096)
         result = xmlrpc.defused_gzip_decode(data, 4096)
-        self.assertEqual(result, b"d" *4096)
+        self.assertEqual(result, b"d" * 4096)
         with self.assertRaises(ValueError):
             result = xmlrpc.defused_gzip_decode(data, 4095)
         with self.assertRaises(ValueError):
@@ -507,7 +467,7 @@ class TestDefusedGzip(DefusedTestCase):
 
         response = self.get_gzipped(4096)
         data = self.decode_response(response)
-        self.assertEqual(data, b"d" *4096)
+        self.assertEqual(data, b"d" * 4096)
 
         with self.assertRaises(ValueError):
             response = self.get_gzipped(4096)
@@ -536,6 +496,7 @@ def test_main():
         suite.addTests(unittest.makeSuite(TestDefusedGzip))
     return suite
 
+
 if __name__ == "__main__":
     suite = test_main()
     result = unittest.TextTestRunner(verbosity=1).run(suite)
